# Youtube Enhanced

The simplest way to interact with Youtube.

You need to set a _PROJECT_ABSOLUTE_PATH_ env variable pointing to your project location path. You must also include a _client-secret.json_ file in the main folder with your Google API information.